Date: 08 27, 2001 9:48:11 AM

# Why Use It?

A developer could use another integrated development environment (IDE) such as Visual C++ to create text analyzers, but developers can rapidly create accurate applications using VisualText™. This is because all the machinery needed to write a non-trivial text analyzer is included in VisualText, while a developer would need to write that machinery first in another programming environment. This machinery includes, for example, rule syntax specification and interpreter, a parse tree builder, an integrated knowledge base, and much more.

In the past, text analyzers could be maintained only by the original developers or by programmers with specialization in natural language processing (NLP) or by computational linguistics. VisualText changes all that, allowing non-programming staff to update text analyzers by adding text examples with simple point-and-click commands.

For further information, see http://www.textanalysis.com.